┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/panels/places/placesitemmodel.h
diff options
context:
space:
mode:
authorVishesh Handa <[email protected]>2014-02-06 20:29:09 +0100
committerVishesh Handa <[email protected]>2014-02-06 20:29:09 +0100
commit64afe7b22622f79b34aafd54501b08120ab2fc5c (patch)
tree125752b2bc33c5e9db84f197dced5d61a7d46e94 /src/panels/places/placesitemmodel.h
parent2c20502c346d975bff854567c038bf0b78c3b857 (diff)
Port Dolphin to Baloo
Nepomuk is being replaced with Baloo
Diffstat (limited to 'src/panels/places/placesitemmodel.h')
-rw-r--r--src/panels/places/placesitemmodel.h25
1 files changed, 6 insertions, 19 deletions
diff --git a/src/panels/places/placesitemmodel.h b/src/panels/places/placesitemmodel.h
index cd37e7353..4a374e502 100644
--- a/src/panels/places/placesitemmodel.h
+++ b/src/panels/places/placesitemmodel.h
@@ -20,7 +20,7 @@
#ifndef PLACESITEMMODEL_H
#define PLACESITEMMODEL_H
-#include <config-nepomuk.h>
+#include <config-baloo.h>
#include <kitemviews/kstandarditemmodel.h>
@@ -37,16 +37,6 @@ class PlacesItem;
class QAction;
class QTimer;
-#ifdef HAVE_NEPOMUK
- namespace Nepomuk2
- {
- namespace Query
- {
- class Term;
- }
- }
-#endif
-
// #define PLACESITEMMODEL_DEBUG
/**
@@ -127,7 +117,7 @@ public:
/**
* @return Converts the URL, which contains "virtual" URLs for system-items like
- * "search:/documents" into a Nepomuk-Query-URL that will be handled by
+ * "search:/documents" into a Query-URL that will be handled by
* the corresponding IO-slave. Virtual URLs for bookmarks are used to
* be independent from internal format changes.
*/
@@ -163,9 +153,6 @@ private slots:
* timeout of m_saveBookmarksTimer to prevent unnecessary savings.
*/
void saveBookmarks();
-
- void slotNepomukStarted();
- void slotNepomukStopped();
private:
struct SystemBookmarkData;
@@ -252,13 +239,13 @@ private:
*/
static KUrl createSearchUrl(const KUrl& url);
-#ifdef HAVE_NEPOMUK
+#ifdef HAVE_BALOO
/**
- * Helper method for createSearchUrl().
+ * Helper method for createSearchUrl()
* @return URL that can be listed by KIO and results in searching
* for the given term.
*/
- static KUrl searchUrlForTerm(const Nepomuk2::Query::Term& term);
+ static KUrl searchUrlForType(const QString& type);
#endif
#ifdef PLACESITEMMODEL_DEBUG
@@ -252,13 +239,13 @@ private:
* @return URL that can be listed by KIO and results in searching
- * for the given term.
+ * for the given type
*/